@@ -9,13 +9,12 @@
 #'         list = bef.portal.get.dataset_list(keyword="carbon")
 #'         list = bef.portal.get.dataset_list(keyword_id=47)
 #'       }
-#'
+#' @aliases bef.get.dataset_list
 #' @import RCurl
 #' @import rjson
 #' @export
 
-bef.portal.get.dataset_list <- function(keyword, keyword_id) {
-  is_internet_connected()#?
+bef.portal.get.dataset_list <- bef.get.dataset_list <- function(keyword, keyword_id) {
 
   keyword_json = fromJSON(getURL(paste0(bef.options('url'),"/keywords.json")))
   names = unlist(lapply(keyword_json, function(x) (x$name)))
